package com.install4j.api.beaninfo;

import com.install4j.runtime.installer.InstallerConstants;

/**
 * Enumeration class for all possible failure strategies of actions.
 * @see ActionBeanInfo#setDefaultFailureStrategy(FailureStrategy)
 */
public enum FailureStrategy {

    /**
     * Continue after a failure.
     */
    CONTINUE(InstallerConstants.FAILURE_STRATEGY_CONTINUE),

    /**
     * Quit after a failure.
     */
    QUIT(InstallerConstants.FAILURE_STRATEGY_QUIT),

    /**
     * Ask the user whether to continue or to quit.
     */
    ASK_USER(InstallerConstants.FAILURE_STRATEGY_ASK_USER),

    /**
     * Ask the user whether to continue, to retry or to quit.
     */
    ASK_USER_RETRY(InstallerConstants.FAILURE_STRATEGY_ASK_USER_RETRY),

    /**
     * No further actions will be executed and the previous screen will be displayed again.
     * If the action is contained the startup node, the first screen will be displayed.
     */
    RETURN_TO_SCREEN(InstallerConstants.FAILURE_STRATEGY_RETURN_TO_SCREEN);

    private int id;

    FailureStrategy(int id) {
        this.id = id;
    }

    /**
     * Convert to an int value.
     * @return the int value
     */
    public int getId() {
        return id;
    }
}
