package com.install4j.api.beans;

import java.awt.*;

/**
 * Property type for an anchor.
 *
 * @author ej-technologies GmbH
 */

public enum Anchor {

    NORTHWEST("North-West", GridBagConstraints.NORTHWEST),
    NORTH("North", GridBagConstraints.NORTH),
    NORTHEAST("North-East", GridBagConstraints.NORTHEAST),
    WEST("West", GridBagConstraints.WEST),
    CENTER("Center", GridBagConstraints.CENTER),
    EAST("East", GridBagConstraints.EAST),
    SOUTHWEST("South-West", GridBagConstraints.SOUTHWEST),
    SOUTH("South", GridBagConstraints.SOUTH),
    SOUTHEAST("South-East", GridBagConstraints.SOUTHEAST);

    /**
     * Get the anchor constant that corresponds to the specified value
     * @param value the value, as returned by {@link #getValue()}
     * @see #getValue()
     * @return the anchor or <tt>null</tt> if the value cannot be found
     */
    public static Anchor getByValue(int value) {
        for (Anchor anchor : values()) {
            if (anchor.getValue() == value) {
                return anchor;
            }
        }
        return null;
    }

    private String verbose;
    private int value;

    Anchor(String verbose, int value) {
        this.verbose = verbose;
        this.value = value;
    }

    /**
     * The value of the anchor which can be used by <tt>java.awt.GridBagLayout</tt>.
     * @return the value, one of the anchor constants in <tt>java.awt.GridBagConstraints</tt>
     */
    public int getValue() {
        return value;
    }

    @Override
    public String toString() {
        return verbose;
    }

}
